==> haskell-conduit-extra-1.3.0-56-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.3.0
id: conduit-extra-1.3.0-8nMAEezxNAE289euQyvZ9j
key: conduit-extra-1.3.0-8nMAEezxNAE289euQyvZ9j
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
abi: f8b8c5579ec6cebc54de4e6701a7832f
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib
import-dirs: /usr/lib/ghc-8.4.3/site-local/conduit-extra-1.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/conduit-extra-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/conduit-extra-1.3.0
hs-libraries: HSconduit-extra-1.3.0-8nMAEezxNAE289euQyvZ9j
depends:
    base-4.11.1.0 conduit-1.3.0.3-2kQyPNl7LmHLxxI2wSVWau
    bytestring-0.10.8.2 text-1.2.3.0 transformers-0.5.5.0
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE directory-1.3.1.5
    filepath-1.4.2 network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc process-1.6.3.0
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q stm-2.4.5.0
    streaming-commons-0.2.1.0-IHjVuLsC1dCG4NgUAHEljH
    unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
    typed-process-0.2.3.0-HsHU3wCtmMN2cnJKsyU9vn
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             conduit-1.3.0.3-2kQyPNl7LmHLxxI2wSVWau=165b50aef4a213b491f6528fa1a2f4d1
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             streaming-commons-0.2.1.0-IHjVuLsC1dCG4NgUAHEljH=600a9a820800b4704fa1de287d187398
             unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS=b3bd63f18add30d59629e9599623cc96
             typed-process-0.2.3.0-HsHU3wCtmMN2cnJKsyU9vn=f690ae7c2dcd9c83ee3ecad05bf5e29b
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.3.0-57-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.3.0
id: conduit-extra-1.3.0-36s7bkvQjhlAr3LyAHLUCy
key: conduit-extra-1.3.0-36s7bkvQjhlAr3LyAHLUCy
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
abi: 841ef3dc13ffd1f4ce7f0bc348a42f4f
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib
import-dirs: /usr/lib/ghc-8.4.3/site-local/conduit-extra-1.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/conduit-extra-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/conduit-extra-1.3.0
hs-libraries: HSconduit-extra-1.3.0-36s7bkvQjhlAr3LyAHLUCy
depends:
    base-4.11.1.0 conduit-1.3.0.3-7hM2y3vt6zPJrBL0QWA5kl
    bytestring-0.10.8.2 text-1.2.3.0 transformers-0.5.5.0
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE directory-1.3.1.5
    filepath-1.4.2 network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc process-1.6.3.0
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q stm-2.4.5.0
    streaming-commons-0.2.1.0-IHjVuLsC1dCG4NgUAHEljH
    unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
    typed-process-0.2.3.0-HsHU3wCtmMN2cnJKsyU9vn
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             conduit-1.3.0.3-7hM2y3vt6zPJrBL0QWA5kl=027922e93a267b72b868d4ff5db4d6d0
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             streaming-commons-0.2.1.0-IHjVuLsC1dCG4NgUAHEljH=600a9a820800b4704fa1de287d187398
             unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS=b3bd63f18add30d59629e9599623cc96
             typed-process-0.2.3.0-HsHU3wCtmMN2cnJKsyU9vn=f690ae7c2dcd9c83ee3ecad05bf5e29b
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
